@@ -1,6 +1,7 @@
 from .fixtures_asset import *
 from .fixtures_auth import *
 from .fixtures_catalog import *
+from .fixtures_tasking import *
 from .fixtures_estimation import *
 from .fixtures_job import *
 from .fixtures_jobcollection import *
@@ -8,7 +9,7 @@ from .fixtures_jobtask import *
 from .fixtures_order import *
 from .fixtures_project import *
 from .fixtures_storage import *
-from .fixtures_tools import *
+from .fixtures_main import *
 from .fixtures_webhook import *
 from .fixtures_workflow import *
 from .fixtures_globals import *
