@@ -6,13 +6,13 @@ import tempfile
 import tarfile
 import zipfile
 import warnings
-import functools
 from datetime import datetime
 from datetime import time as datetime_time
+from functools import wraps
 
 from geopandas import GeoDataFrame
 import shapely
-from shapely.geometry import Polygon
+from shapely.geometry import Polygon, Point
 from geojson import Feature, FeatureCollection
 from geojson import Polygon as geojson_Polygon
 import requests
@@ -62,7 +62,7 @@ def deprecation(
     """
 
     def actual_decorator(func):
-        @functools.wraps(func)
+        @wraps(func)
         def wrapper(*args, **kwargs):
             message = (
                 f"`{func.__name__}` will be deprecated in version {version}, "
@@ -225,14 +225,7 @@ def format_time_period(
 
 
 def any_vector_to_fc(
-    vector: Union[
-        dict,
-        Feature,
-        FeatureCollection,
-        list,
-        GeoDataFrame,
-        Polygon,
-    ],
+    vector: Union[dict, Feature, FeatureCollection, list, GeoDataFrame, Polygon, Point],
     as_dataframe: bool = False,
 ) -> Union[dict, GeoDataFrame]:
     """
@@ -240,8 +233,7 @@ def any_vector_to_fc(
 
     Args:
         vector: One of dict, FeatureCollection, Feature, list of bounds coordinates,
-            GeoDataFrame, shapely.geometry.Polygon.
-            All assume EPSG 4326 and Polygons!
+            GeoDataFrame, shapely.Polygon, shapely.Point. All assume EPSG 4326!
         as_dataframe: GeoDataFrame output with as_dataframe=True.
     """
     if not isinstance(
@@ -254,11 +246,12 @@ def any_vector_to_fc(
             list,
             GeoDataFrame,
             Polygon,
+            Point,
         ),
     ):
         raise ValueError(
             "The provided geometry muste be a FeatureCollection, Feature, dict, geopandas "
-            "Dataframe, shapely Polygon or a list of 4 bounds coordinates."
+            "Dataframe, shapely Polygon, Point or a list of 4 bounds coordinates."
         )
 
     vector = copy.deepcopy(vector)  # avoid altering input geometry
@@ -283,7 +276,7 @@ def any_vector_to_fc(
                 df = GeoDataFrame({"geometry": [box_poly]}, crs=4326)
             else:
                 raise ValueError("The list requires 4 bounds coordinates.")
-        elif isinstance(vector, Polygon):
+        elif isinstance(vector, (Polygon, Point)):
             df = GeoDataFrame({"geometry": [vector]}, crs=4326)
         elif isinstance(vector, GeoDataFrame):
             df = vector
@@ -374,3 +367,37 @@ def filter_jobs_on_mode(
     jobs_json = [job for job in jobs_json if job["mode"] in selected_modes]
     logger.info(f"Returning {selected_modes} jobs.")
     return jobs_json
+
+
+def autocomplete_order_parameters(order_parameters: dict, schema: dict):
+    """
+    Adds missing required catalog/tasking order parameters and logs parameter suggestions.
+
+    Args:
+        order_parameters: The initial order_parameters, in format
+            {"dataProduct": data_product_id, "params" : {...}}
+        schema: The data product parameter schema from .get_data_product_schema
+        The existing order parameter params
+
+    Returns:
+        The order parameters with complete params
+    """
+    additional_params = {
+        param: None
+        for param in schema["required"]
+        if param not in order_parameters["params"]
+    }
+    order_parameters["params"] = dict(order_parameters["params"], **additional_params)
+
+    # Log message help for parameter selection
+    for param in additional_params.keys():
+        if param in ["aoi", "geometry"]:
+            continue
+        elif "allOf" in schema["properties"][param]:  # has further definitions key
+            potential_values = [x["id"] for x in schema["definitions"][param]["enum"]]
+            logger.info(f"As `{param}` select one of {potential_values}")
+        else:
+            # Full information for simple parameters
+            del schema["properties"][param]["title"]
+            logger.info(f"As `{param}` select `{schema['properties'][param]}`")
+    return order_parameters
