@@ -16,8 +16,7 @@ from up42.auth import Auth
 from up42.job import Job
 from up42.estimation import Estimation
 from up42.jobcollection import JobCollection
-from up42.asset import Asset
-from up42.tools import Tools
+
 from up42.utils import (
     get_logger,
     any_vector_to_fc,
@@ -25,6 +24,7 @@ from up42.utils import (
     filter_jobs_on_mode,
     format_time_period,
 )
+import up42.main as main
 
 logger = get_logger(__name__)
 
@@ -102,11 +102,9 @@ class Workflow:
         if not tasks:
             logger.info("The workflow is empty, returning all data blocks.")
 
-            logging.getLogger("up42.tools").setLevel(logging.CRITICAL)
-            data_blocks = Tools(auth=self.auth).get_blocks(
-                block_type="data", basic=True
-            )
-            logging.getLogger("up42.tools").setLevel(logging.INFO)
+            logging.getLogger("up42.main").setLevel(logging.CRITICAL)
+            data_blocks = main.get_blocks(block_type="data", basic=True)
+            logging.getLogger("up42.main").setLevel(logging.INFO)
             return data_blocks  # type: ignore
 
         last_task = list(tasks.keys())[-1]
@@ -145,8 +143,9 @@ class Workflow:
         else:
             return tasks
 
+    @staticmethod
     def _construct_full_workflow_tasks_dict(
-        self, input_tasks: Union[List]
+        input_tasks: Union[List[str], List[dict]]
     ) -> List[dict]:
         """
         Constructs the full workflow task definition from a simplified version.
@@ -177,9 +176,9 @@ class Workflow:
         full_input_tasks_definition = []
 
         # Get public + custom blocks.
-        logging.getLogger("up42.tools").setLevel(logging.CRITICAL)
-        blocks: dict = Tools(auth=self.auth).get_blocks(basic=False)  # type: ignore
-        logging.getLogger("up42.tools").setLevel(logging.INFO)
+        logging.getLogger("up42.main").setLevel(logging.CRITICAL)
+        blocks: dict = main.get_blocks(basic=False)  # type: ignore
+        logging.getLogger("up42.main").setLevel(logging.INFO)
 
         # Get ids of the input tasks, regardless of the specified format.
         blocks_id_name = {block["id"]: block["name"] for block in blocks}
@@ -306,7 +305,7 @@ class Workflow:
     def _get_default_parameters(self) -> dict:
         """
         Gets the default parameters for the workflow that can be directly used to
-        run a job. Excludes geometry operation and geometry of the data block.
+        run a job.
         """
         default_workflow_parameters = {}
 
@@ -318,10 +317,17 @@ class Workflow:
             task_parameters = task["block"]["parameters"]
 
             default_task_parameters = {}
-
+            # Add parameters if they have non-None default or are required (use default or otherwise None)
             for param_name, param_values in task_parameters.items():
-                if "default" in param_values and param_values["default"] is not None:
+                if "default" in param_values:
                     default_task_parameters[param_name] = param_values["default"]
+                if (
+                    "required" in param_values
+                    and param_name not in default_task_parameters
+                ):
+                    # required without default key, add as placeholder
+                    if param_values["required"]:
+                        default_task_parameters[param_name] = None
 
             default_workflow_parameters[task_name] = default_task_parameters
         return default_workflow_parameters
@@ -341,8 +347,9 @@ class Workflow:
         start_date: Optional[Union[str, datetime]] = None,
         end_date: Optional[Union[str, datetime]] = None,
         limit: Optional[int] = None,
-        scene_ids: Optional[list] = None,
-        assets: Optional[List[Asset]] = None,
+        scene_ids: Optional[List[str]] = None,
+        asset_ids: Optional[List[str]] = None,
+        **kwargs,
     ) -> dict:
         """
         Constructs workflow input parameters with a specified aoi, the default input parameters, and
@@ -359,34 +366,37 @@ class Workflow:
             end_date: Query period ending day as iso-format or datetime object,
                 e.g. "YYYY-MM-DD" or "YYYY-MM-DDTHH:MM:SS".
             scene_ids: List of scene_ids, if given ignores all other parameters except geometry.
-            assets: Optional, can be used to incorporate existing assets in Storage (result
+            asset_ids: Optional, can be used to incorporate existing assets in Storage (result
                 of Orders for instance) into new workflows.
 
         Returns:
             Dictionary of constructed input parameters.
         """
+        logger.info(
+            "See `workflow.get_workflow_tasks() for more detail on the parameters options."
+        )
+
         input_parameters = self._get_default_parameters()
         try:
             data_block_name = list(input_parameters.keys())[0]
         except IndexError as e:
             raise ValueError("The Workflow has no workflow tasks.") from e
 
-        if assets is not None:
-            # Needs to be handled in this function(not run_job) as it is only
-            # relevant for the data block.
-            asset_ids = [asset.asset_id for asset in assets if asset.source == "BLOCK"]
-            if not asset_ids:
-                raise ValueError(
-                    "None of the assets are usable in a workflow since the source is not `BLOCK`."
-                )
+        if asset_ids is not None:
+            input_parameters[data_block_name] = {"asset_ids": asset_ids}
+        elif "assets" in kwargs:
+            logger.warning(
+                "The use of the parameter `assets` is deprecated and will be removed in v0.26.0, "
+                "use `asset_ids` as a list of ids instead!"
+            )
+            assets = kwargs["assets"]
+            asset_ids = [asset.asset_id for asset in assets]
             input_parameters[data_block_name] = {"asset_ids": asset_ids}
         else:
             if limit is not None:
                 input_parameters[data_block_name]["limit"] = limit
 
             if scene_ids is not None:
-                if not isinstance(scene_ids, list):
-                    scene_ids = [scene_ids]
                 input_parameters[data_block_name]["ids"] = scene_ids
                 input_parameters[data_block_name]["limit"] = len(scene_ids)
                 input_parameters[data_block_name].pop("time")
@@ -404,7 +414,6 @@ class Workflow:
                     fc=aoi_fc,
                     geometry_operation=geometry_operation,  # type: ignore
                 )
-
                 input_parameters[data_block_name][geometry_operation] = aoi_feature
         return input_parameters
 
